@@ -2,7 +2,7 @@
  * Remmina - The GTK+ Remote Desktop Client
  * Copyright (C) 2010 Vic Lee
  * Copyright (C) 2014-2015 Antenore Gatta, Fabio Castelli, Giovanni Panozzo
- * Copyright (C) 2016-2022 Antenore Gatta, Giovanni Panozzo
+ * Copyright (C) 2016-2023 Antenore Gatta, Giovanni Panozzo
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -120,6 +120,20 @@ static gboolean disable_rcw_delete_confirm_cb(GtkWidget *widget, gpointer data)
 	return TRUE;
 }
 
+void remmina_exec_exitremmina_one_confirm()
+{
+	TRACE_CALL(__func__);
+	GtkWidget* dialog = gtk_message_dialog_new(NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_QUESTION,
+							GTK_BUTTONS_YES_NO,
+							_("Are you sure you want to fully quit Remmina?\n This will close any active connections."));
+			int response = gtk_dialog_run(GTK_DIALOG(dialog));
+			gtk_widget_destroy(dialog);
+			if (response != GTK_RESPONSE_YES)
+				return;
+	remmina_widget_pool_foreach(disable_rcw_delete_confirm_cb, NULL);
+	remmina_exec_exitremmina();
+}
+
 void remmina_application_condexit(RemminaCondExitType why)
 {
 	TRACE_CALL(__func__);
